@@ -54,7 +54,7 @@ sub construct {
     my $t = "$test_dir/script/test003.1.sh";
 
     MooseX::App::ParsedArgv->new(
-        argv => [ "submit_jobs", "--infile", $t, "--hpc_plugins", "Dummy", ]
+        argv => [ "submit_jobs", "--infile", $t, "--dry_run" ]
     );
 
     my $test = HPC::Runner::Command->new_with_command();
@@ -80,30 +80,30 @@ sub test_003 : Tags(construct) {
     remove_tree($test_dir);
 }
 
-sub test_004 : Tags(submit_jobs) {
-    my $cwd      = getcwd();
-    my $test = construct();
-    my $test_dir = getcwd();
-
-    $test->parse_file_slurm();
-    $test->iterate_schedule();
-
-    ok(1);
-
-    chdir($cwd);
-    remove_tree($test_dir);
-}
-
-sub test_005 : Tags(submit_jobs) {
-    my $cwd      = getcwd();
-    my $test = construct();
-    my $test_dir = getcwd();
-
-    $test->execute();
-
-    ok(1);
-    chdir($cwd);
-    remove_tree($test_dir);
-}
+# sub test_004 : Tags(submit_jobs) {
+#     my $cwd      = getcwd();
+#     my $test = construct();
+#     my $test_dir = getcwd();
+#
+#     $test->parse_file_slurm();
+#     $test->iterate_schedule();
+#
+#     ok(1);
+#
+#     chdir($cwd);
+#     remove_tree($test_dir);
+# }
+#
+# sub test_005 : Tags(submit_jobs) {
+#     my $cwd      = getcwd();
+#     my $test = construct();
+#     my $test_dir = getcwd();
+#
+#     $test->execute();
+#
+#     ok(1);
+#     chdir($cwd);
+#     remove_tree($test_dir);
+# }
 
 1;
